@@ -3,7 +3,7 @@ from __future__ import print_function
 import os
 import os.path
 import time
-from typing import Callable
+from typing import Callable, List
 
 import gspread
 import numpy as np
@@ -108,7 +108,9 @@ def _create_gsheets_table_aux(
         columns_default_unit=columns_default_unit, gsheets_value_and_formats=True
     )
     table_width = len(species_table[0])
-    full_table = [[mix.mix_name] + [""] * (table_width - 1)] + species_table
+    # full_table = [[mix.mix_name] + [""] * (table_width - 1)] + species_table
+    # ^ In fact name will be copied later from layout sheet
+    full_table = species_table
     if add_total_line:
         full_table += [
             ["Total"]
@@ -124,6 +126,7 @@ def create_gsheets_table(
     add_total_line: bool = True,
     columns_default_unit=True,
     show_units_when_default_units=False,
+    extra_columns=[],
 ):
     """
     Transforms a mix into a gsheets table (and returns additional gsheets formatting info)
@@ -157,6 +160,15 @@ def create_gsheets_table(
                 table[-1].append(val)
                 format_table[-1].append(None)
 
+    for col in extra_columns:
+        for i, row in enumerate(table):
+            # Check needed because of extra total line
+            if i < len(col):
+                row.append(col[i])
+            else:
+                row.append("")
+            format_table[i].append(None)
+
     return table, format_table
 
 
@@ -295,6 +307,7 @@ def create_targets(
     workbook,
     layout_sheet,
     mix_parser: Callable[[str], FixedVolumeMix],
+    extra_columns_function: Callable[[FixedVolumeMix], List] = lambda x: [],
     max_col_size=4,
     merge_repeats=True,
     add_total_line=True,
@@ -320,6 +333,8 @@ def create_targets(
 
     mix_parser: a function that, given a description of a mix outpus a `FixedVolumeMix`.
 
+    extra_columns_function: a function that takes a mix and returns extra gsheets column to add.
+
     max_col_size: the maximum number of columns of any target's table.
 
     merge_repeats: should mixes corresponding to the same sample be mixed in the Targets' sheet.
@@ -422,6 +437,7 @@ def create_targets(
                 add_total_line=add_total_line,
                 columns_default_unit=columns_default_unit,
                 show_units_when_default_units=show_units_when_default_units,
+                extra_columns=extra_columns_function(mix),
             )
             print(f"Placing target `{sample_desc}`")
             if print_mixes:
@@ -432,7 +448,10 @@ def create_targets(
                 targets_sheet,
                 table,
                 format_table,
-                top_left_origin=(current_row, current_col),
+                top_left_origin=(
+                    current_row,
+                    current_col,
+                ),
                 banding_ID=k,
             )
             requests += r
@@ -459,7 +478,6 @@ def create_targets(
                             "startColumnIndex": current_col,
                             "endColumnIndex": current_col + 1,
                         },
-                        "pasteType": "PASTE_FORMAT",
                     }
                 }
             )
